#!/bin/bash
#
# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#
set -Eeuo pipefail

# Constants
SCRIPT_DIR="$(dirname "$(readlink -f "$0")")"

# Arguments
while (($# > 0)); do
  if [[ "$1" == "--version" ]]; then
    lightdash_version="${2}"
    shift 2
  else
    echo "WARN: unrecognized argument ${1}" >&2
    shift 1
  fi
done


# Download swagger.json from the GitHub repository
url="https://raw.githubusercontent.com/lightdash/lightdash/${lightdash_version:?}/packages/backend/src/generated/swagger.json"
curl "${url:?}" --output "${SCRIPT_DIR}/swagger.json"
